@@ -572,7 +572,7 @@ returns the same as File::Copy::copy() in scalar context and 1,0,0 in list conte
 =head2 dircopy()
 
 This function recursively traverses the $orig directory's structure and recursively copies it to the $new directory.
-$new is created if necessary (multiple non existant directories is ok (IE foo/bar/baz). The script logically and portably creates all of them if necessary).
+$new is created if necessary (multiple non existent directories is ok (IE foo/bar/baz). The script logically and portably creates all of them if necessary).
 It attempts to preserve the mode (see Preserving Mode below) and 
 by default it copies all the way down into the directory, (see Managing Depth) below.
 If a directory is not specified it croaks just like fcopy croaks if its not a file that is specified.
@@ -593,7 +593,7 @@ That way it will copy everythgingit can ina directory and won't stop because of
 
 This function will allow you to specify a file *or* directory. It calls fcopy() if its a file and dircopy() if its a directory.
 If you call rcopy() (or fcopy() for that matter) on a file in list context, the values will be 1,0,0 since no directories and no depth are used. 
-This is important becasue if its a directory in list context and there is only the initial directory the return value is 1,1,1.
+This is important because if it's a directory in list context and there is only the initial directory the return value is 1,1,1.
 
 =head2 rcopy_glob()
 
@@ -654,11 +654,11 @@ Any value you set it to should be suitable for oct()
 
 =head3 Path functions
 
-These functions exist soley because they were necessary for the move and copy functions to have the features they do and not because they are of themselves the purpose of this module. That being said, here is how they work so you can understand how the copy and move funtions work and use them by themselves if you wish.
+These functions exist solely because they were necessary for the move and copy functions to have the features they do and not because they are of themselves the purpose of this module. That being said, here is how they work so you can understand how the copy and move funtions work and use them by themselves if you wish.
 
 =head4 pathrm()
 
-Removes a given path recursively. It removes the *entire* path so be carefull!!!
+Removes a given path recursively. It removes the *entire* path so be careful!!!
 
 Returns 2 if the given path is not a directory.
 
@@ -810,7 +810,7 @@ This is false by default so that a check is done to see if the source directory
 
 If you ever find a situation where $CopyLoop = 1 is desirable let me know (IE its a bad bad idea but is there if you want it)
 
-(Note: On Windows this was necessary since it uses stat() to detemine samedness and stat() is essencially useless for this on Windows. 
+(Note: On Windows this was necessary since it uses stat() to detemine samedness and stat() is essentially useless for this on Windows.
 The test is now simply skipped on Windows but I'd rather have an actual reliable check if anyone in Microsoft land would care to share)
 
 =head1 SEE ALSO
